@@ -1,14 +1,12 @@
 package Perl::Dist::Inno::Icon;
 
-use 5.006;
 use strict;
-use warnings;
 use Carp         qw{ croak               };
 use Params::Util qw{ _IDENTIFIER _STRING };
 
 use vars qw{$VERSION};
 BEGIN {
-	$VERSION = '0.90_03';
+	$VERSION = '0.30';
 }
 
 use Object::Tiny qw{
@@ -51,10 +49,10 @@ sub new {
 sub as_string {
 	my $self = shift;
 	return join( '; ',
-		"Name: \""     . $self->name . "\"",
-		"Filename: \"" . $self->filename . "\"",
+		"Name: "     . $self->name,
+		"Filename: " . $self->filename,
 		defined($self->working_dir)
-			? ("WorkingDir: \"" . $self->working_dir . "\"")
+			? ("WorkingDir: " . $self->working_dir)
 			: (),
 	);
 }
