@@ -1,14 +1,12 @@
 package Perl::Dist::Inno::Registry;
 
-use 5.006;
 use strict;
-use warnings;
 use Carp         qw{ croak               };
 use Params::Util qw{ _IDENTIFIER _STRING };
 
 use vars qw{$VERSION};
 BEGIN {
-	$VERSION = '0.90_03';
+	$VERSION = '0.30';
 }
 
 use Object::Tiny qw{
