@@ -13,7 +13,7 @@ use t::lib::Test3 ();
 
 use vars qw{$VERSION};
 BEGIN {
-	$VERSION = '0.90_03';
+	$VERSION = '0.30';
 }
 
 
@@ -42,11 +42,13 @@ sub paths {
 	# Prepare the test directories
 	my $output_dir   = remake_path( "C:\\tmp\\sp\\output"   );
 	my $image_dir    = remake_path( "C:\\tmp\\sp\\image"    );
+	my $source_dir   = remake_path( "C:\\tmp\\sp\\source"   );
 	my $download_dir =   make_path( "C:\\tmp\\sp\\download" );
 	my $build_dir    = remake_path( "C:\\tmp\\sp\\build"    );
 	return (
 		output_dir   => $output_dir,
 		image_dir    => $image_dir,
+		source_dir   => $source_dir,
 		download_dir => $download_dir,
 		build_dir    => $build_dir,
 	);
