@@ -1,11 +1,11 @@
 package t::lib::Test1;
 
 use strict;
-use base 'Perl::Dist::Inno';
+use base 'Perl::Dist';
 
 use vars qw{$VERSION};
 BEGIN {
-	$VERSION = '0.90_03';
+	$VERSION = '0.30';
 }
 
 
